/*******************************************************************************
* File Name: Main.c
* Version: 1.0, Created on 2014/04/30
*
* DESCRIPTION: main.c demo code of Proximity Detection using CY3280-21x34 UCC demo kit
*
* Note:
*
********************************************************************************
* Copyright (2011), Cypress Semiconductor Corporation. All rights reserved.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign),United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating 
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement. 
*******************************************************************************/

/***********************************************************************************************
                                THEORY OF OPERATION

* This project demonsrates the proximity detection using CY3280-21x34 UCC kit.

Hardware and Software Setup:

* Connect a 10cm wire in loop for to P0_0 pin on the P2 connector of CY3280-21x34 kit.
* Connect MiniProg3(used as I2C to USB bridge)to the ISSP header of CY3280-21x34 kit. 
* Open Bridge Control Panel software from the path Start->All Programs->Cypress->Bridge Control Panel 
* Open “Variable Setting” window from Chart->Variable Settings on Bridge Control Panel Software. 
* Enter 3 integer variables named RawCount, Baseline and DiffCount and one Byte variable named Status and 
  click on OK.
* Click on Tools->Protocol Configuration->I2C on BCP and select 100KHz and click on OK.
* Enter the following commands in Editor Window of BCP (Bridge Control Panel).

	w 04 0
	r 04 @1RawCount @0RawCount @1Baseline @0Baseline @1DiffCount @0DiffCount @Status
	
* Click on the “Toggle Power” button shown in the bottom of BCP window to power the board using MiniProg3.
* Keep the cursor on the first command (w 04 0) in Editor window of BCP and press Enter.
* Keep the cursor on the second command line in Editor window and click on “Repeat”.

Testing the Project:

* Click on “Chart” tab on the BCP and select the plot “Status” listed on the top right corner.
* Bring the hand towards the wire loop and observe on BCP that the status variable becomes 1.
* Deselect the Status plot and select the plot “RawCount” to see the profile of Raw counts.
*************************************************************************************************/

//Part specific constants and macros
#include <m8c.h>        
//PSoC API definitions for all User Modules
#include "PSoCAPI.h"    

struct I2C_Regs
{	
	//Variable that holds the Raw Count value
	WORD RawCount;
	//Variable that holds the Baseline value
	WORD Baseline;
	//Variable that holds the Difference Count value
	WORD Difference;
	//Variable that holds the ON/OFF status of the sensor
	BYTE Status;
}My_I2CRegs;

void main(void)
{
	//Enable the Global Interrupt
	M8C_EnableGInt;
	
	//Start the CSD user module
	CSD_Start();
	
	//Initialize the baselines
	CSD_InitializeBaselines();
	
	//Move the Finger Threshold value entered in CSD Parameter window to CSD_baBtnFThreshold[] array
	CSD_SetDefaultFingerThresholds();
	
	//Expose the I2C RAM buffer to I2C master
	EzI2Cs_SetRamBuffer(sizeof(My_I2CRegs), 0, (BYTE *)&My_I2CRegs);
	
	//Start the EzI2Cs user module
	EzI2Cs_Start();
	
	while(1)
	{
		//Scan the sensor connected to P0_0
		CSD_ScanSensor(0);
		
		//call the RawCount tracking or baseline update algorithm
		CSD_UpdateSensorBaseline(0);
		
		//store the RawCount value of proximity sensor into the I2C buffer
		My_I2CRegs.RawCount = CSD_waSnsResult[0];
		
		//store the Baseline value of proximity sensor into the I2C buffer
		My_I2CRegs.Baseline = CSD_waSnsBaseline[0];

		//store the Difference count value of proximity sensor into the I2C buffer
		My_I2CRegs.Difference = CSD_waSnsDiff[0];
		
		//If the proximity sensor is activated
		if(CSD_bIsSensorActive(0))
		{
			//store 1 in the Status variable of I2C buffer
			My_I2CRegs.Status = 1;	
		}
		//Otherwise
		else
		{
			//store 0 in the Status variable of I2C buffer
			My_I2CRegs.Status = 0;	
		}
	}
}
